
module Hermes
  class Api::HousingRequestSharesController < ActionController::Base
    before_action :set_housing_request_share, only: :show

    def show
      return redirect_to "/apps/hermes-infos-demande/?id=#{params[:id]}&code=#{params[:code]}" if !request.format.json?
      Hermes::LogJob.perform_later(
        code: 'HOUSING_REQUEST_SHARES',
        action: "show",
        housing_request_id: @housing_request_share.housing_request.id.to_s
      )

      return render(json: { message: :expired_housing_request_share }, status: 498) unless valid_expiration_date?

      if @housing_request_share.code == params[:code]
        render(
          jsonapi: @housing_request_share,
          serializer: PublicHousingRequestShareSerializer,
          include: [
            housing_request: {
              housing_request_folder: {
                include: [:required_documents]
              }
            }
          ]
        )
      else
        render json: { message: :invalid_code }, status: :not_found
      end
    end

    private

    def set_housing_request_share
      @housing_request_share = Hermes::HousingRequestShare.find(params[:id])
      return render json: { message: :invalid_housing_request_share }, status: :not_found unless @housing_request_share
    end

    def valid_expiration_date?
      @housing_request_share.expire_at >= DateTime.current
    end
  end 
end 
