# frozen_string_literal: true

class AlsIdUniqJob < ActiveJob::Base
 
  queue_as :als_id_generation
  unique :until_executed

  def perform(id, force_als_id = nil)
    if hr = Hermes::HousingRequest.find(id)
      not_unique = true
      max_try = 5
      counter = 0

      while not_unique && counter < 5
        begin
          counter += 1
          generate_als_id(hr, force_als_id)
          hr.save!
          not_unique = false
        rescue => e
          break if e.class == Mongo::Error::OperationFailure || /als_id_1 dup key/.match(e.message)
          sleep(1)
        end
      end
    end 
  end

  def generate_als_id(hr, force_als_id = nil)
    return hr.als_id = force_als_id unless force_als_id.nil?
    als_id = nil
    while als_id.nil? || Hermes::HousingRequest.find_by(als_id: als_id) 
      max = Hermes::HousingRequest.all.only(:als_id).sort({als_id:-1}).limit(1).first&.als_id || format('%010d', 0)
      als_id = format('%010d', max.to_i + 1)
      hr.als_id = als_id
      break
    end
  end
end