# frozen_string_literal: true

module Hermes
  class LessorObjectiveHistory
    include Hermes::Concerns::CommonFieldsConcern

    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id

    field :target_by_typologies, type: Hash, default: {}
    field :realized_by_typologies, type: Hash, default: {}
    field :lessor_objective_id, type: BSON::ObjectId
    field :lessor_id, type: BSON::ObjectId
    field :housing_offer_id, type: BSON::ObjectId

    belongs_to :lessor_objective, class_name: 'Hermes::LessorObjective', foreign_key: :lessor_objective_id

    validates_presence_of :lessor_objective_id

    common_indexes *%i[
      lessor_objective_id
      lessor_id
      housing_offer_id
    ]

    before_create :before_create_actions

    def before_create_actions
      set_objective_attributes
    end

    def set_objective_attributes
      %i[lessor_id target_by_typologies realized_by_typologies].each do |attribute|
        self[attribute] = lessor_objective[attribute]
      end
    end
  end
end
