# frozen_string_literal: true

module Hermes
  # Applicant serializer
  class ApplicantSerializer < Hermes::ApplicationSerializer
    cache key: proc { "#{object.cache_key}#{object.first_active_request&.updated_at}" }, expires_in: 1.day
    
    attributes %i[
      nud
      temporary_id
      sne_profile_creation_date
      ss_id
      first_name
      last_name
      full_name
      patronymic_name
      nationality
      email
      email_advances_assistant
      event_notification
      cellphone
      homephone
      workphone
      civility
      birth_date
      work_contract_type
      profession_details
      has_other_employers
      main_employer_name
      main_employer_siret
      workplace_postal_code
      workplace_locality
      foreign_workplace_postal_code
      foreign_workplace_locality
      foreign_workplace_country
      year_minus_one
      amount_year_minus_one
      year_minus_two
      amount_year_minus_two
      ressources_details
      tax_revenues
      apl_amount
      family_situation
      family_situation_validated
      asked_children_nb
      valid_children_nb
      asked_family_size
      valid_family_size
      situation_tax_treshold
      status
      status_updated_at
      asked_locataire_hlm
      valid_locataire_hlm
      valid_priority_public
      asked_priority_public
      priority_public
      mobility
      mutation
      completed_requests_nb
      on_going_request_nb
      disability
      renewal_date
      eligibility_query
      actual_housing_details
      postal_details
      is_owner
      owned_housing_details
      housing_request_ids
      entity_id
      active_housing_request_id
      application_ids
      sms_notification
      main_user_id
      workplace_insee_code
      notification_subscription_id
      unique_numbers
    ]
    
    # active_housing_request_id
    # application_ids
    # eligible_offers_nb
    
    # updated_status_at
    attribute :actual_housing_details, key_transformation: :unaltered
    attribute :monthly_incomes, key_transformation: :unaltered
    attribute :monthly_charges, key_transformation: :unaltered
    
    type 'applicants'
    
    def initialize(*params)
      #Rails.logger.debug "TEST START #{(@t = Time.now)}"
      super(*params)
    end 
    
    # def active_housing_request
    #   Hermes::HousingRequestSerializer.new(
    #     object.first_active_request,
    #     scope: scope,
    #     root: false
    #   ) if object.first_active_request
    # end
    
    def first_active_request
      #t = Time.now
      @request ||= object.first_active_request
      #Rails.logger.debug "  TEST E 1 #{(Time.now - t)}"
    end

    def unique_numbers
      object.first_active_request&.unique_numbers
    end
    
    ELIGIBILITY_FIELDS = %i[
      single_min_family_size
      couple_min_family_size
      max_family_size
      min_revenues
      surface
      is_public
      single_parent
      typology
      priority_public
      reserved
      mutation
    ].concat(
      %w[ceil, floor].each do |label|
        (1..12).each {|i| "#{label}_category_#{i}".to_sym}
      end
    )
    #TODO : optimize on fly to db (ndt : optimiser : de calcul à la volée en enregistrement en bdd . )
    def eligible_offers_nb
      #t = Time.now
      eligibility = JSON.parse(object.eligibility_query)
                      .each_with_object({}) do |(key, val), h|
        h[key.to_sym] = val unless val.nil?
      end
      
      #Rails.logger.debug ""
      r = Hermes::HousingOffer.only(*ELIGIBILITY_FIELDS).count(**eligibility)
      #Rails.logger.debug "  TEST E 2 #{(Time.now - t)}"
      #Rails.logger.debug "TEST END #{Time.now - @t}"
      r
    end
    
    def main_user_id
      object.main_user_id&.to_s
    end
    
    def active_housing_request_id
      first_active_request&.id.to_s
    end
    
    def housing_request_ids
      object.housing_request_ids&.map(&:to_s)
    end
    
    def entity_id
      id = object.entity_id.to_s
      id
    end
    
    def application_ids
      ids = first_active_request&.housing_application_ids&.map(&:to_s)
      ids
    end

    def notification_subscription_id
      object.subscription.id.to_s
    end
    
    # def owned_housing_details
    #   it=object.owned_housing_details
    #   Rails.logger.debug "TEST END #{Time.now - @t}"
    #   it
    # end
  end
end
