# frozen_string_literal: true

module Hermes
  class HousingRequestLightSerializer < Hermes::ApplicationSerializer
    cache key: proc {"#{object.cache_key}"}, expires_in: 1.day
    type 'housing_requests'

    attribute :als_id
    attribute :profile_epci_score
    attribute :applicated_position
    attribute :eligible_position
    attribute :effort_rate

    def score
      return unless instance_options[:scores]

      @score ||= instance_options[:scores].select do |score|
        score.applicant_id == object.main_applicant_id
      end.first
    end
    
    def handle_score_value(value)
      value.nil? ? 'uneligible' : value
    end
    
    def profile_epci_score
      handle_score_value score&.profile_epci_score
    end
    
    def applicated_position
      handle_score_value score&.applicated_position
    end
    
    def eligible_position
      handle_score_value score&.eligible_position
    end
    
    def effort_rate
      handle_score_value score&.effort_rate
    end
  end
end
