# frozen_string_literal: true

# Return Hermes::Applicant attributes from parsed xml

module Hermes
  module BoClient
    module Mappings
      class ApplicantReverseMap        
        def initialize(xml, is_main_applicant, coapplicant_index = nil)
          @xml                = xml
          @is_main_applicant  = is_main_applicant
          @coapplicant_index  = coapplicant_index
        end

        def build_applicant
          demande_logement = @xml["interfaceNuu"]["demande"]["demandeLogement"] #["personnePhysique"]["demandeur"]["mel"]
          personnePhysique = demande_logement["personnePhysique"]

          if @is_main_applicant
            demandeur = personnePhysique["demandeur"]
          else
            demandeur = (personnePhysique["listeCotitulaire"].is_a? Array) ? personnePhysique["listeCotitulaire"][@coapplicant_index]["cotitulaire"] : personnePhysique["listeCotitulaire"]["cotitulaire"]
          end

          # On récupère les valeurs du sne et on vérifie si les années correspondent a N-1 et N-2 de l'année courante
          # On sauvegardera les valeurs de montantMoins1 et montantMoins2 qu'en cas de correspondance des années fiscales
          year_minus_one            = demandeur["revenuFiscal"]&.fetch("anneeMoins1", nil)
          valid_year_minus_one      = (DateTime.current.year - 1).to_s
          has_valid_year_minus_one  = year_minus_one&.to_s == valid_year_minus_one
          year_minus_two            = demandeur["revenuFiscal"]&.fetch("anneeMoins2", nil)
          valid_year_minus_two      = (DateTime.current.year - 2).to_s
          has_valid_year_minus_two  = year_minus_two&.to_s == valid_year_minus_two
          amount_year_minus_one     = has_valid_year_minus_one ? demandeur["revenuFiscal"]&.fetch("montantMoins1", nil) : nil
          amount_year_minus_two     = has_valid_year_minus_two ? demandeur["revenuFiscal"]&.fetch("montantMoins2", nil) : nil
          # Si nous somme en 2020 (N-1 = 2019 et N-2 = 2018) et que nous avons sur le sne (N-1 = 2018 et N-2 = 2017) alors on attribut le montant de N-1 du sne à N-2 en base
          unless has_valid_year_minus_two
            amount_year_minus_two = demandeur["revenuFiscal"]&.fetch("montantMoins1", nil) if year_minus_one&.to_s == valid_year_minus_two
          end

          attributes = {
            nationality: demandeur["nationalite"]&.fetch("code", nil),
            civility: demandeur["civilite"]&.fetch("code", nil),
            birth_date: demandeur["dateNaissance"],
            homephone: demandeur["telDomicile"],
            workphone: demandeur["telTravail"],
            cellphone: demandeur["telPortable"],
            has_other_employers: demandeur["situationProfessionnelle"]&.fetch("multiEmployeur", nil),
            year_minus_one: valid_year_minus_one,
            amount_year_minus_one: amount_year_minus_one,
            year_minus_two: valid_year_minus_two,
            amount_year_minus_two: amount_year_minus_two,
            family_situation: demandeur["situationFamiliale"]&.fetch("code", nil),
            email_advances_assistant: demandeur['melAssistantDemarches']
          }

          if @is_main_applicant
            attributes[:actual_housing_details] = {}
            adresseLogement = personnePhysique["adresseLogement"] || {}
            logementActuel = personnePhysique["logementActuel"] || {}
            attributes[:actual_housing_details]['etranger'] = adresseLogement["etranger"]
            attributes[:actual_housing_details]['appartment_number'] = adresseLogement["appartement"]
            attributes[:actual_housing_details]['appartment_floor'] = adresseLogement["etage"]
            attributes[:actual_housing_details]['appartment_staircase'] = adresseLogement["escalier"]
            attributes[:actual_housing_details]['appartment_building'] = adresseLogement["batiment"]
            attributes[:actual_housing_details]['address_add_address'] = adresseLogement["compAdresse"]
            attributes[:actual_housing_details]['appartment_address_place'] = adresseLogement["lieuDit"]
            attributes[:actual_housing_details]['address_number'] = adresseLogement["numero"]
            attributes[:actual_housing_details]['way'] = adresseLogement["voie"]
            attributes[:actual_housing_details]['postal_code'] = adresseLogement["codePostal"]
            attributes[:actual_housing_details]['address_insee_code'] = adresseLogement["commune"]&.fetch("code", nil)
            attributes[:actual_housing_details]['houser_name'] = adresseLogement["nomHebergeant"]
            attributes[:actual_housing_details]['current_address_postal_code'] = adresseLogement["codePostalEtranger"]
            attributes[:actual_housing_details]['foreign_city'] = adresseLogement["communeEtranger"]
            attributes[:actual_housing_details]['foreign_country'] = adresseLogement["pays"]
            attributes[:actual_housing_details]['monthly_rental_amount'] = logementActuel["montantMensuelLoyer"].to_s
            attributes[:actual_housing_details]['APL_monthly_amount'] = logementActuel["montantMensuelAPL"].to_s
            attributes[:actual_housing_details]['type'] = logementActuel["typeLogementActuel"]&.fetch("code", nil)
            attributes[:actual_housing_details]['number_of_resident'] = logementActuel["nombreHabitant"]
            attributes[:actual_housing_details]['area'] = logementActuel["surface"]
            attributes[:actual_housing_details]['housing_category_list'] = logementActuel["categorieLogement"]&.fetch("code", nil)
            attributes[:actual_housing_details]['number_of_resident'] = logementActuel["nombreHabitant"]
            attributes[:actual_housing_details]['housing_surface'] = logementActuel["surface"]
            attributes[:actual_housing_details]['is_house_owner'] = logementActuel["proprietaire"]
            attributes[:actual_housing_details]['housing_category_list'] = logementActuel["categorieLogement"]&.fetch("code", nil)
            attributes[:actual_housing_details]['typeLogementActuel'] = logementActuel["typeLogementActuel"]&.fetch("code", nil)

            if logementActuel["proprietaire"]
              attributes[:owned_housing_details] = attributes[:actual_housing_details]
              attributes[:owned_housing_details]['type']  = logementActuel["typeLogementPossede"]&.fetch("code", nil) if logementActuel["typeLogementPossede"]&.fetch("code", nil)
            end
          else
            attributes[:temporary_id] = demandeur['identifiantTemporaire']
          end

          attributes[:ss_id] = demandeur["nir"]
          attributes[:first_name] = demandeur['prenom']
          attributes[:last_name] = demandeur["nom"]
          attributes[:patronymic_name] = demandeur["nomPatronymique"]
          attributes[:email] = demandeur["mel"]
          attributes[:sms_notification] = (demandeur["notifSms"] != "false") if demandeur["notifSms"]
          attributes[:event_notification] = (demandeur["notifEvt"] != "false") if demandeur["notifEvt"]
          attributes[:work_contract_type] = demandeur["situationProfessionnelle"]&.fetch("typeContratTravail")&.fetch("code", nil)
          attributes[:monthly_incomes] = {}
          demandeur['listeRessourceRecue'] = demandeur['listeRessourceRecue'].is_a?(Array) ? demandeur['listeRessourceRecue'] : [demandeur['listeRessourceRecue']]

          demandeur['listeRessourceRecue']&.each do |ressource|
            if ressource
              detailRessource = ressource["detailRessource"].is_a?(Array) ? ressource["detailRessource"] : [ressource["detailRessource"]]
              detailRessource.each do |detail|
                attributes[:monthly_incomes][detail["ressource"]&.fetch("code", nil).to_s] = detail["montant"].to_i
              end
            end
          end

          attributes[:monthly_charges] = {}
          demandeur['listeRessourceVersee'] = demandeur['listeRessourceVersee'].is_a?(Array) ? demandeur['listeRessourceVersee'] : [demandeur['listeRessourceVersee']]
          demandeur['listeRessourceVersee']&.each do |ressource|
            if ressource
              detailRessource = ressource["detailRessource"].is_a?(Array) ? ressource["detailRessource"] : [ressource["detailRessource"]]
              detailRessource.each do |detail|
                attributes[:monthly_charges][detail["ressource"]&.fetch("code", nil).to_s] = detail["montant"].to_i
              end
            end
          end

          attributes[:profession_details] = {}
          if demandeur['situationProfessionnelle']['etranger']
            if (demandeur['situationProfessionnelle']['etranger'] == "false")
              attributes[:profession_details]["foreign"] = false
            else
              attributes[:profession_details]["foreign"] = true
            end
          end

          attributes[:profession_details]["profession"] = demandeur['situationProfessionnelle']['profession']
          attributes["workplace_postal_code"] = demandeur['situationProfessionnelle']['codePostal']
          attributes[:foreign_workplace_postal_code] = demandeur['situationProfessionnelle']['codePostalEtranger']
          attributes[:foreign_workplace_locality] = demandeur['situationProfessionnelle']['communeEtranger']
          attributes[:foreign_workplace_country] = demandeur['situationProfessionnelle']['pays']
          attributes[:workplace_insee_code] = demandeur['situationProfessionnelle']['commune']&.fetch("code", nil).to_s
          attributes[:main_employer_name] = demandeur['situationProfessionnelle']['nomEmployeurPrincipal']
          attributes[:main_employer_siret] = demandeur['situationProfessionnelle']['siretEmployeur']

          attributes
        end
      end
    end
  end
end
