require 'rails_helper'
require 'vcr_config'


dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'EntrepriseDemande.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::ValidateEntityTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
  let!(:entity1) { create(:entity, title: "dd entreprise", siret: "12345678901234", id_rex:"truc") }
  let!(:applicant1) {
    create(
        :applicant,
        user: user1,
        monthly_charges: {},
        work_contract_type: "AGP",
        has_other_employers: true,
        nationality: "1",
        family_situation:'V',
        year_minus_one: Date.current.year,
        amount_year_minus_one: "123",
        birth_date:Date.current,
    entity: entity1,
        civility:"1",
        sne_profile_creation_date: Date.current - 20.days,
        actual_housing_details:{
=begin
            'appartment_staircase': "33",

            "housing_surface": "200",
            'appartment_building': "A",

            "address_add_address":"à droite  con !!!!!!!!!!!",
            "APL_monthly_amount":"120","number_of_resident": "2",
            "monthly_rental_amount": "380",
            'address_actual_housing_details':{"code":30100},
            'appartment_floor':'1',
=end

"housing_typology":"1",
            "address_number": "36",
            "address_street": "Allée de ta mere" ,
           # appartment_address_place: " ",
            postal_code:"29000",
            address_insee_code: "29000"
        },

        )
  }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:applicant) {create(:applicant)}


    let!(:housing_request1) do
      create(
          :housing_request,
          is_active: true,
          main_applicant: applicant1,
          id_counter: "alpha",

          internal_ref: "alpha",
          seeked_localisation_list: [
              {
                  "nom": "Fréjus",
                  "code": "83061",
                  "codeDepartement": "83",
                  "codeRegion": "93",
                  "codesPostaux": [
                      "83600",
                      "83370"
                  ],
                  "population": 53168,
                  "_score": 1
              },
              {
                  "nom": "Fréjzus",
                  "code": "84061",
                  "codeDepartement": "81",
                  "codeRegion": "92",
                  "codesPostaux": [
                      "80600",
                      "80370"
                  ],
                  "population": 53168,
                  "_score": 1
              },
          ],
          forcing_duplicate: true,
          electronical_renewal: true,
          seeked_housing_categories: ["J"],
          seeking_first_floor: true,
          seeking_elevator: true,
          seeked_max_rent: 451,

          widen_request: true,
          seeked_types: ["T1", "T2"],
          typology_range: ["T1"],
          housing_type_list:["HLM"],
         postal_details:{
             'appartment_number':30,
             "host": 'A',
             'address_postal_details':{'code': "30100"},
             'appartment_floor':'1',
             "address_number": "36",
             "address_street": "Allée de ta mere",
             appartment_address_place: " ",
             postal_code:"29000",
             address_insee_code:"29199"
         },
          requester_lastname: "alpha",
          requester_firstname: "alpha",
          is_house_owner: true,
          motivation1: "02",
          motivation3: "01",

      )
    end
    let!(:nud3) do
      create(
          :nud,
          housing_request: housing_request1,
          department: '14',
          creation_date: '2017-23-14T14:53:22',
          unique_number:"54739274"
      )
    end

    describe 'using to_xml' do
      let!(:add_request_task1) do
        build(
            :validate_entity_task,
            options: {nud_id: housing_request1.nud_ids[0] ,housing_request_id: housing_request1.reload.id }
        )
      end
      it 'should return a valid xml' do
        xsd.validate(Nokogiri::XML(add_request_task1.to_xml))
        add_request_task1.validate_xml
        ap add_request_task1.to_xml
        expect(housing_request1.reload.last_xml_validation_report).to eq("[]")
        so=Hermes::BoClient::ValidateEntityTask.new({:'housing_request_id'=> housing_request1.id})
        so.execute
        VCR.use_cassette("flux36", :match_requests_on => [:method, :uri, :path]) do
          drain_all_jobs
        end
      
        expect(housing_request1.reload.last_send_has_error).to eq(true)
        
        expect(xsd.validate(Nokogiri::XML(add_request_task1.to_xml)).length).to eq(0)
      end
    end
  end
end
